@@ -53,7 +53,7 @@ def app():
             elif just_logged_in:
                 print()
                 puts(colored.green(f"       Welcome Back, {user['username']}"))
-                print(colored.green('---------------------------------------------------'))
+                print(colored.green('--------------------------------------------------'))
         with indent(3):
             puts(colored.magenta('         ------Main Menu-----'))
             puts(colored.cyan('To view latest gossips          -----> 1'))
@@ -81,6 +81,7 @@ def app():
                         puts(colored.blue("To get a specific post           ----> press 3"))
                         puts(colored.magenta(70 * '-'))
 
+
                     gossips_display_choice = check_input('1', '2', '3', help_text='  ~~~> ')
                     if gossips_display_choice == '1':
                         value = display_gossips(data['gossips'], gossips_display_choice)
@@ -246,7 +247,6 @@ def app():
                                     comment_on_gossip(context["gossip"]["id"], user)
                                 else:
                                     main_menu(user)
-
                     else:
                         main_menu(user)
                 else:
@@ -256,6 +256,5 @@ def app():
 
     logged_out_menu()
 
-
 app()
 
